@@ -4,8 +4,9 @@ from pydantic import (
 from typing import Optional, List
 
 
-class Meta(BaseModel):
+class PredictMeta(BaseModel):
     webhooks: Optional[HttpUrl]
+    transfer_bucket: Optional[str] = "captur-ml-test"
 
 
 class TrainingMeta(BaseModel):
